// Copyright (c) 2019, the EOMarch project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

/// Wrapper for `Exception` or `Error` with `StackTrace` (if it have been provided)
class PackageException {
  /// Ctor for auto recognition of `error` type
  PackageException(dynamic error, [this.stackTrace])
      : innerError = error is Error ? error : null,
        innerException = error is Exception ? error : null;

  /// Ctor for wrapping `Exception`
  PackageException.fromException(this.innerException, [this.stackTrace])
      : innerError = null;

  /// Ctor for wrapping `Error`
  PackageException.fromError(this.innerError, [this.stackTrace])
      : innerException = null;

  /// Inner exception, might be null if `PackageException` have been created `fromError`
  final Exception innerException;

  /// Inner error, might be null if `PackageException` have been created `fromException`
  final Error innerError;

  /// Current `StackTrace`, if provided
  final StackTrace stackTrace;

  /// Gets current `Exception` or `Error`
  dynamic get currentError => innerError ?? innerException;
}
