// Copyright (c) 2019, the EOMarch project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'package:flutter_test/flutter_test.dart';

import 'package:package_exception_handler/package_exception_handler.dart';

void main() {
  test('PkgExc ctor with Exception (null) without StackTrace', () {
    var pkgExc = PackageException.fromException(null);
    expect(null, pkgExc.stackTrace);
    expect(null, pkgExc.innerError);
    expect(null, pkgExc.innerException);
    expect(null, pkgExc.currentError);
  });

  test('PkgExc ctor with Exception (null) with StackTrace', () {
    var st = StackTrace.current;
    var pkgExc = PackageException.fromException(null, st);
    expect(st, pkgExc.stackTrace);
    expect(null, pkgExc.innerError);
    expect(null, pkgExc.innerException);
    expect(null, pkgExc.currentError);
  });

  test('PkgExc ctor with Exception without StackTrace', () {
    var exc = FormatException();
    var pkgExc = PackageException.fromException(exc);
    expect(null, pkgExc.stackTrace);
    expect(null, pkgExc.innerError);
    expect(exc, pkgExc.innerException);
    expect(exc, pkgExc.currentError);
  });

  test('PkgExc ctor with Exception with StackTrace', () {
    var exc = FormatException();
    var st = StackTrace.current;
    var pkgExc = PackageException.fromException(exc, st);
    expect(st, pkgExc.stackTrace);
    expect(null, pkgExc.innerError);
    expect(exc, pkgExc.innerException);
    expect(exc, pkgExc.currentError);
  });

  test('PkgExc ctor with Error (null) without StackTrace', () {
    var pkgExc = PackageException.fromError(null);
    expect(null, pkgExc.stackTrace);
    expect(null, pkgExc.innerException);
    expect(null, pkgExc.innerError);
    expect(null, pkgExc.currentError);
  });

  test('PkgExc ctor with Error (null) with StackTrace', () {
    var st = StackTrace.current;
    var pkgExc = PackageException.fromError(null, st);
    expect(st, pkgExc.stackTrace);
    expect(null, pkgExc.innerException);
    expect(null, pkgExc.innerError);
    expect(null, pkgExc.currentError);
  });

  test('PkgExc ctor with Error without StackTrace', () {
    var error = ArgumentError();
    var pkgExc = PackageException.fromError(error);
    expect(null, pkgExc.stackTrace);
    expect(null, pkgExc.innerException);
    expect(error, pkgExc.innerError);
    expect(error, pkgExc.currentError);
  });

  test('PkgExc ctor with Error with StackTrace', () {
    var error = ArgumentError();
    var st = StackTrace.current;
    var pkgExc = PackageException.fromError(error, st);
    expect(st, pkgExc.stackTrace);
    expect(null, pkgExc.innerException);
    expect(error, pkgExc.innerError);
    expect(error, pkgExc.currentError);
  });
}
